@@ -26,6 +26,8 @@ import sys
 import time
 import warnings
 
+from six.moves import range
+
 def setugid(user):
     """Change process user and group ID
 
@@ -77,7 +79,7 @@ def daemonize(pidfile=None, uid=None, umask=077):
     for i in range(3):
         try:
             os.dup2(null, i)
-        except OSError, e:
+        except OSError as e:
             if e.errno != errno.EBADF:
                 raise
     os.close(null)
