@@ -17,10 +17,11 @@
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """unittest module for logilab.comon.testlib"""
 
+from __future__ import print_function
+
 import os
 import sys
 from os.path import join, dirname, isdir, isfile, abspath, exists
-from cStringIO import StringIO
 import tempfile
 import shutil
 
@@ -29,6 +30,9 @@ try:
 except NameError:
     __file__ = sys.argv[0]
 
+from six.moves import range
+
+from logilab.common.compat import StringIO
 from logilab.common.testlib import (unittest, TestSuite, unittest_main, Tags,
     TestCase, mock_object, create_files, InnerTest, with_tempdir, tag,
     require_version, require_module)
@@ -101,9 +105,9 @@ class TestlibTC(TestCase):
 
     def test_list_equals(self):
         """tests TestCase.assertListEqual"""
-        l1 = range(10)
-        l2 = range(5)
-        l3 = range(10)
+        l1 = list(range(10))
+        l2 = list(range(5))
+        l3 = list(range(10))
         self.assertRaises(AssertionError, self.tc.assertListEqual, l1, l2)
         self.tc.assertListEqual(l1, l1)
         self.tc.assertListEqual(l1, l3)
@@ -259,7 +263,7 @@ class GenerativeTestsTC(TestCase):
     def test_generative_ok(self):
         class FooTC(TestCase):
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield self.assertEqual, i, i
         result = self.runner.run(FooTC('test_generative'))
         self.assertEqual(result.testsRun, 10)
@@ -269,7 +273,7 @@ class GenerativeTestsTC(TestCase):
     def test_generative_half_bad(self):
         class FooTC(TestCase):
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield self.assertEqual, i%2, 0
         result = self.runner.run(FooTC('test_generative'))
         self.assertEqual(result.testsRun, 10)
@@ -279,7 +283,7 @@ class GenerativeTestsTC(TestCase):
     def test_generative_error(self):
         class FooTC(TestCase):
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     if i == 5:
                         raise ValueError('STOP !')
                     yield self.assertEqual, i, i
@@ -292,7 +296,7 @@ class GenerativeTestsTC(TestCase):
     def test_generative_error2(self):
         class FooTC(TestCase):
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     if i == 5:
                         yield self.ouch
                     yield self.assertEqual, i, i
@@ -307,7 +311,7 @@ class GenerativeTestsTC(TestCase):
             def setUp(self):
                 raise ValueError('STOP !')
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield self.assertEqual, i, i
 
         result = self.runner.run(FooTC('test_generative'))
@@ -324,7 +328,7 @@ class GenerativeTestsTC(TestCase):
                     self.assertEqual(val, val)
 
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield InnerTest("check_%s"%i, self.check, i)
 
         result = self.runner.run(FooTC('test_generative'))
@@ -342,7 +346,7 @@ class GenerativeTestsTC(TestCase):
                     self.assertEqual(val, val)
 
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield InnerTest("check_%s"%i, self.check, i)
 
         result = self.runner.run(FooTC('test_generative'))
@@ -360,7 +364,7 @@ class GenerativeTestsTC(TestCase):
                     self.assertEqual(val, val)
 
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield InnerTest("check_%s"%i, self.check, i)
 
         result = self.runner.run(FooTC('test_generative'))
@@ -378,7 +382,7 @@ class GenerativeTestsTC(TestCase):
                     self.assertEqual(val, val)
 
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield InnerTest("check_%s"%i, self.check, i)
 
         result = self.runner.run(FooTC('test_generative'))
@@ -418,7 +422,7 @@ class ExitFirstTC(TestCase):
     def test_generative_exit_first(self):
         class FooTC(TestCase):
             def test_generative(self):
-                for i in xrange(10):
+                for i in range(10):
                     yield self.assert_, False
         result = self.runner.run(FooTC('test_generative'))
         self.assertEqual(result.testsRun, 1)
@@ -531,7 +535,7 @@ class TestLoaderTC(TestCase):
             class MyTestCase(TestCase):
                 def test_foo(self): pass
                 def test_foobar(self):
-                    for i in xrange(5):
+                    for i in range(5):
                         if i%2 == 0:
                             yield InnerTest('even', lambda: None)
                         else:
@@ -709,8 +713,8 @@ class DecoratorTC(TestCase):
                     not exist : function return by the decorator should \
                     NOT be the same.' % module)
                 return
-        print 'all modules in %s exist. Could not test %s' % (', '.join(modules),
-            sys._getframe().f_code.co_name)
+        print('all modules in %s exist. Could not test %s' % (', '.join(modules),
+              sys._getframe().f_code.co_name))
 
 class TagTC(TestCase):
 
